#line 1 "wimaxasncp_dict.c"
/* Include this before everything else, for various large-file definitions */
#include "config.h"
#include <wireshark.h>

#line 6 "wimaxasncp_dict.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define WimaxasncpDict__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer WimaxasncpDict__create_buffer
#endif

#ifdef yy_delete_buffer
#define WimaxasncpDict__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer WimaxasncpDict__delete_buffer
#endif

#ifdef yy_scan_buffer
#define WimaxasncpDict__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer WimaxasncpDict__scan_buffer
#endif

#ifdef yy_scan_string
#define WimaxasncpDict__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string WimaxasncpDict__scan_string
#endif

#ifdef yy_scan_bytes
#define WimaxasncpDict__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes WimaxasncpDict__scan_bytes
#endif

#ifdef yy_init_buffer
#define WimaxasncpDict__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer WimaxasncpDict__init_buffer
#endif

#ifdef yy_flush_buffer
#define WimaxasncpDict__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer WimaxasncpDict__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define WimaxasncpDict__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state WimaxasncpDict__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define WimaxasncpDict__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer WimaxasncpDict__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define WimaxasncpDict_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state WimaxasncpDict_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define WimaxasncpDict_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state WimaxasncpDict_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define WimaxasncpDict_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack WimaxasncpDict_ensure_buffer_stack
#endif

#ifdef yylex
#define WimaxasncpDict_lex_ALREADY_DEFINED
#else
#define yylex WimaxasncpDict_lex
#endif

#ifdef yyrestart
#define WimaxasncpDict_restart_ALREADY_DEFINED
#else
#define yyrestart WimaxasncpDict_restart
#endif

#ifdef yylex_init
#define WimaxasncpDict_lex_init_ALREADY_DEFINED
#else
#define yylex_init WimaxasncpDict_lex_init
#endif

#ifdef yylex_init_extra
#define WimaxasncpDict_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra WimaxasncpDict_lex_init_extra
#endif

#ifdef yylex_destroy
#define WimaxasncpDict_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy WimaxasncpDict_lex_destroy
#endif

#ifdef yyget_debug
#define WimaxasncpDict_get_debug_ALREADY_DEFINED
#else
#define yyget_debug WimaxasncpDict_get_debug
#endif

#ifdef yyset_debug
#define WimaxasncpDict_set_debug_ALREADY_DEFINED
#else
#define yyset_debug WimaxasncpDict_set_debug
#endif

#ifdef yyget_extra
#define WimaxasncpDict_get_extra_ALREADY_DEFINED
#else
#define yyget_extra WimaxasncpDict_get_extra
#endif

#ifdef yyset_extra
#define WimaxasncpDict_set_extra_ALREADY_DEFINED
#else
#define yyset_extra WimaxasncpDict_set_extra
#endif

#ifdef yyget_in
#define WimaxasncpDict_get_in_ALREADY_DEFINED
#else
#define yyget_in WimaxasncpDict_get_in
#endif

#ifdef yyset_in
#define WimaxasncpDict_set_in_ALREADY_DEFINED
#else
#define yyset_in WimaxasncpDict_set_in
#endif

#ifdef yyget_out
#define WimaxasncpDict_get_out_ALREADY_DEFINED
#else
#define yyget_out WimaxasncpDict_get_out
#endif

#ifdef yyset_out
#define WimaxasncpDict_set_out_ALREADY_DEFINED
#else
#define yyset_out WimaxasncpDict_set_out
#endif

#ifdef yyget_leng
#define WimaxasncpDict_get_leng_ALREADY_DEFINED
#else
#define yyget_leng WimaxasncpDict_get_leng
#endif

#ifdef yyget_text
#define WimaxasncpDict_get_text_ALREADY_DEFINED
#else
#define yyget_text WimaxasncpDict_get_text
#endif

#ifdef yyget_lineno
#define WimaxasncpDict_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno WimaxasncpDict_get_lineno
#endif

#ifdef yyset_lineno
#define WimaxasncpDict_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno WimaxasncpDict_set_lineno
#endif

#ifdef yyget_column
#define WimaxasncpDict_get_column_ALREADY_DEFINED
#else
#define yyget_column WimaxasncpDict_get_column
#endif

#ifdef yyset_column
#define WimaxasncpDict_set_column_ALREADY_DEFINED
#else
#define yyset_column WimaxasncpDict_set_column
#endif

#ifdef yywrap
#define WimaxasncpDict_wrap_ALREADY_DEFINED
#else
#define yywrap WimaxasncpDict_wrap
#endif

#ifdef yyalloc
#define WimaxasncpDict_alloc_ALREADY_DEFINED
#else
#define yyalloc WimaxasncpDict_alloc
#endif

#ifdef yyrealloc
#define WimaxasncpDict_realloc_ALREADY_DEFINED
#else
#define yyrealloc WimaxasncpDict_realloc
#endif

#ifdef yyfree
#define WimaxasncpDict_free_ALREADY_DEFINED
#else
#define yyfree WimaxasncpDict_free
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define WimaxasncpDict_wrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 61
#define YY_END_OF_BUFFER 62
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[333] =
    {   0,
        0,    0,   24,   24,    0,    0,    7,    7,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   30,   30,
       31,   31,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   62,   61,   27,   24,   24,   27,
       27,   27,   20,   26,   21,   27,    4,    4,   61,    4,
        7,    8,   16,   61,   61,   18,   61,   29,   30,   30,
       30,   30,   61,   31,   31,   31,   31,   61,   38,   33,
       35,   37,   39,   40,   60,   60,   61,   61,   61,   41,

       41,   61,   61,   55,   61,   61,   61,   50,   61,   61,
       61,   61,   13,   13,   61,   13,   13,   13,   10,   12,
       24,    0,   20,   26,   21,    0,    0,   25,    0,   22,
       20,    0,   23,    6,   26,   21,    0,    2,    0,    0,
        0,    7,    8,   16,    0,    0,    0,   18,    0,   19,
       29,   30,   30,   30,   30,    0,   31,   31,   31,   31,
        0,   38,   33,   35,   37,   39,    0,    0,    0,    0,
        0,    0,   42,    0,   59,   56,    0,    0,   51,    0,
        0,    0,    0,    0,    0,    0,    0,   14,    0,    0,
       10,   12,   28,   22,    0,    0,    0,   23,    6,    2,

        5,    0,   19,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   14,    0,    0,    3,
        0,    0,    5,    0,    0,    0,    0,   44,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        3,    0,    0,    0,    0,    0,    0,    0,   52,   59,
       59,    0,    0,   59,    0,   59,    0,    9,    0,    0,
        0,    0,    0,    0,    0,   57,   54,   53,    0,    0,
       45,   59,   47,    0,    0,    0,    0,    0,   17,    0,
        0,    0,    0,    0,   49,    0,   11,    0,   15,    0,
        0,    0,   59,    0,    0,   15,    0,    0,    0,   48,

        0,    0,    1,    0,    0,    0,    0,    1,    0,    0,
        0,    0,    0,   43,    0,   59,    0,   58,   46,    0,
        0,    0,    0,    0,    0,    0,   36,    0,   34,    0,
       32,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    1,    1,    1,    7,    1,    8,
        9,    1,    1,    1,   10,    1,   11,   12,   13,   14,
       15,   16,   16,   17,   16,   18,   16,    1,   19,   20,
       21,   22,   23,    1,   24,   25,   26,   27,   28,   29,
       30,   30,   31,   30,   32,   33,   34,   35,   36,   37,
       30,   38,   39,   40,   41,   42,   43,   44,   45,   30,
       46,    1,   47,    1,   48,    1,   49,   50,   51,   52,

       53,   29,   30,   30,   54,   30,   55,   56,   57,   58,
       59,   60,   30,   61,   62,   63,   64,   65,   66,   67,
       68,   30,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[69] =
    {   0,
        1,    1,    1,    1,    1,    2,    1,    1,    1,    3,
        1,    3,    3,    3,    3,    3,    3,    3,    1,    1,
        4,    1,    1,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    1,    1,    1,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3
    } ;

static const flex_int16_t yy_base[359] =
    {   0,
        0,    0,    0,    6,   21,   30,   53,  101,  149,  197,
       75,   78,  639,  638,  607,  594,  591,  556,  236,    0,
      293,    0,  116,  164,  212,  257,  281,  314,  552,  548,
      540,  536,   15,   16,    9,   23,    0,    0,  508,  489,
       35,   36,  346,  404,  452,  505,  399,  415,  502,  471,
      463,  455,    0,    0,  448, 1090, 1090,  464,  479,  439,
        0,  418,  359,   42,   46,   63, 1090,   84,   87,  427,
       66,    0,    0,  229,   47,    0,  139,    0,  171,  557,
       49,  521,   65,  222,  613,   69,  535,  136, 1090,  321,
      361,  371,    0, 1090, 1090,  112,    0,  152,  405, 1090,

      423,  370,  368, 1090,  154,  291,  358, 1090,  393,  411,
      226,  256, 1090,  557,  591,  334,  214,  232,    0,    0,
      632,  319,  518,  207,  356,  491,  308, 1090,  294,  396,
      440,  622,  469,  494,  503,  515,  574,  588,  601,  294,
      270,  613,    0,    0,  616,   99,  216,    0,  665,  656,
        0,  676,  392,    0,    0,  419,  683,  421,    0,    0,
      447, 1090,  690,  697,  704,    0,  458,  273,  469,  503,
      529,  278, 1090,  237, 1090, 1090,  503,  627, 1090,  702,
      703,  704,  705,  727,  219,  343,  371,  668,  553,  699,
        0,    0, 1090,  679,  213,  697,  699,  741,  744,  764,

      768,  695,  771,  627,  701,  707,  698,  721,  735,  757,
      758,  759,  762,  763,  768,  769,  798,  802,  757,  805,
      761,  763,  825,  786,  771,  777,  794, 1090,  782,  791,
      201,  191,  809,  811,  186,  813,  173,  848,  840,  803,
      851,  795,  806,  823,  835,  831,  823,  171, 1090,  185,
      168,  843,  844,  156,  125,  129,  875, 1090,  885,  822,
      828,  891,  837,  846,  861, 1090, 1090, 1090,  862,  880,
     1090,  121, 1090,  900,  905,  873,  867,  916, 1090,  878,
      879,  880,  105,  903, 1090,  923, 1090,  900,  928,  908,
      914,  906,  105,  921,   52,  942,  910,  910,  925, 1090,

      929,   49,  952,   36,  912,  920,  941,  965,  935,   61,
      916,   50,  941, 1090,   41,   46,  933, 1090, 1090,  964,
       34,   23,  157,  274,  426,  981, 1090,  984, 1090,  985,
     1090, 1090,  999, 1003, 1007, 1011, 1015, 1019, 1023, 1027,
     1031, 1035, 1039, 1043, 1047, 1051, 1055,   12,   11,    2,
     1059, 1063, 1067, 1071, 1073, 1077, 1081, 1085
    } ;

static const flex_int16_t yy_def[359] =
    {   0,
      333,  333,  334,  334,  335,  335,  336,  336,  337,  337,
      333,  333,  338,  338,  333,  333,  339,  339,  333,   19,
      333,   21,  333,  333,  333,  333,  333,  333,  340,  340,
      333,  333,  341,  341,  333,  333,  333,  333,  333,  333,
      342,  342,  343,  343,   44,   44,  344,  344,  345,  345,
      346,  346,  333,  333,  332,  332,  332,  332,  332,  347,
      348,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  349,  350,  332,  332,  351,  332,  352,  332,  332,
       80,   80,  332,  332,  332,   85,   85,  332,  332,  332,
      332,  332,  353,  332,  332,  332,  348,  332,  332,  332,

      354,  355,  332,  332,  355,  355,  332,  332,  355,  355,
      355,  355,  332,  332,  332,  332,  332,  332,  356,  357,
      332,  332,  332,  332,  332,  332,  347,  332,  348,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  349,  350,  332,  332,  332,  351,  332,  332,
      352,  332,   80,   82,   82,  332,  332,   85,   87,   87,
      332,  332,  332,  332,  332,  353,  332,  332,  332,  332,
      332,  354,  332,  355,  332,  332,  355,  355,  332,  355,
      355,  355,  355,  332,  332,  332,  332,  332,  332,  332,
      356,  357,  332,  332,  332,  332,  332,  332,  332,  332,

      332,  332,  332,  332,  332,  332,  332,  332,  332,  355,
      355,  355,  355,  355,  355,  355,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      355,  355,  355,  355,  355,  355,  355,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  355,  355,  332,  355,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  355,  355,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  355,  355,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  355,  358,  332,  332,  332,  332,  332,

      355,  358,  332,  332,  332,  332,  355,  332,  332,  332,
      332,  355,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,    0,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332
    } ;

static const flex_int16_t yy_nxt[1159] =
    {   0,
      332,   58,   59,   58,  144,   60,   61,   58,   59,   58,
       62,   60,   61,  143,  129,   97,   62,   56,   56,   63,
       64,   65,   68,   69,   68,   63,   64,   65,   98,   97,
       70,   68,   69,   68,   96,   96,  325,   56,   56,   70,
      101,  101,   98,  135,  135,  135,   66,  136,  136,  136,
      324,  319,   66,   56,   71,   71,   71,   56,   56,   56,
       56,   56,  318,   56,  137,  137,  137,  142,  142,  142,
      316,   56,   56,   56,   56,   56,   74,   74,   74,   74,
       74,   74,  314,  309,  138,  139,  139,  139,  139,  139,
      139,  147,  332,  140,  303,  156,  140,  303,   56,   56,

       56,   56,   71,   71,   71,   56,   56,   56,   56,   56,
      300,   56,  332,   75,  147,  332,   75,   88,  156,   56,
       56,   56,   56,   56,   89,  293,  285,   90,   90,   90,
       90,   90,   90,   90,  273,  332,   75,  161,  167,   75,
      149,  149,  149,  147,  162,  272,   56,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   56,  326,   56,
      150,  271,  168,  167,  327,   88,  147,   56,   56,   56,
       56,   56,   89,  268,  175,   90,   90,   90,   90,   90,
       90,   90,  152,  152,  152,  152,  152,  152,  152,  177,
      267,  169,  266,  256,   56,   56,   56,   56,   56,   56,

       56,   56,   56,   56,   56,   56,  254,   56,  135,  135,
      135,  251,  177,   88,  169,   56,   56,   56,   56,   56,
       89,  250,  220,   91,   91,   91,   91,   91,   91,   91,
      145,  145,  145,  157,  157,  157,  157,  157,  157,  157,
      188,  189,   56,   56,   56,   79,  175,   80,   81,   81,
       81,   81,   81,   81,  202,  190,  182,  175,   88,   82,
       82,   82,   82,   82,   82,   89,  189,  146,   91,   91,
       91,   91,   91,   91,   91,  328,  175,  202,   83,  182,
      190,  329,   88,  173,   82,   82,   82,   82,   82,   89,
      146,  201,   92,   92,   92,   92,   92,   92,   92,  206,

      183,   83,   84,  141,   85,   86,   86,   86,   86,   86,
       86,  175,  193,  128,  178,   88,   87,   87,   87,   87,
       87,   87,   89,  183,  206,   92,   92,   92,   92,   92,
       92,   92,  163,  163,  163,  163,  163,  163,  163,  178,
      130,   87,   87,   87,   87,   87,   56,   56,   56,   56,
       56,   56,   56,   56,   56,  188,  103,  136,  136,  136,
      131,  131,  131,  132,   56,   56,   56,  104,   56,  133,
      189,  105,  164,  164,  164,  164,  164,  164,  164,  179,
      106,  134,  165,  165,  165,  165,  165,  165,  165,  176,
      175,   56,   56,   56,  190,  189,  105,  194,  194,  194,

      114,  115,  114,  106,   56,   56,   56,   56,   56,   56,
       56,   56,   56,  175,  103,  170,  114,  115,  114,  190,
      180,  116,   56,   56,   56,  104,   56,  330,  173,  105,
      117,  175,  171,  331,  181,  332,  141,  116,  106,  130,
      118,  131,  131,  131,  128,  180,  117,  332,  161,   56,
       56,   56,  204,  117,  105,  162,  118,  171,  332,  181,
       56,  106,  107,  118,  332,  121,  121,  121,   56,  117,
      198,  198,  198,  108,  122,  204,   56,  102,  109,  118,
      121,  121,  121,  123,  124,  125,  110,  332,  205,  122,
      111,  112,  137,  137,  137,  199,  199,  199,  123,  124,

      125,  207,  102,  109,  135,  135,  135,   56,   99,  110,
      126,  205,  138,  111,  112,  107,  136,  136,  136,  131,
      131,  131,  132,  175,  207,  126,  108,   99,  133,  210,
      102,  109,  154,  154,  154,  154,  154,  154,  154,  110,
      134,   94,  208,  111,  112,   94,  159,  159,  159,  159,
      159,  159,  159,   56,  210,  102,  109,   56,  184,  184,
      184,   56,  110,  209,  332,  208,  111,  112,  153,  153,
      153,  153,  153,  153,  153,  137,  137,  137,  332,  185,
      154,  154,  154,  154,  154,  154,  209,  332,  186,  200,
      200,  200,  184,  184,  184,  138,   56,  218,  187,   77,

      155,  332,  139,  139,  139,  154,  154,  154,  154,  154,
      140,  186,   77,  185,  142,  142,  142,  145,  145,  145,
      218,  187,  186,  155,  158,  158,  158,  158,  158,  158,
      158,  195,  187,  121,  121,  121,  159,  159,  159,  159,
      159,  159,  122,   56,   56,  186,  332,  175,  196,  197,
      225,  123,  124,  125,  146,  187,  160,  203,  203,  203,
      211,  159,  159,  159,  159,  159,  149,  149,  149,  217,
      217,  217,  332,  196,  197,  225,  332,  146,  126,  160,
      194,  194,  194,  211,  332,  332,  150,  152,  152,  152,
      152,  152,  152,  152,  157,  157,  157,  157,  157,  157,

      157,  163,  163,  163,  163,  163,  163,  163,  164,  164,
      164,  164,  164,  164,  164,  165,  165,  165,  165,  165,
      165,  165,  175,  175,  175,  175,  226,  212,  184,  184,
      184,  219,  221,  222,  224,  332,  214,  227,  215,  228,
      213,  216,  198,  198,  198,  199,  199,  199,  332,  185,
      332,  226,  212,  229,  219,  221,  222,  224,  186,  214,
      227,  215,  228,  213,  216,  200,  200,  200,  187,  223,
      223,  223,  203,  203,  203,  230,  229,  175,  175,  175,
      332,  186,  175,  175,  231,  232,  242,  234,  175,  175,
      235,  187,  332,  236,  233,  332,  237,  240,  230,  217,

      217,  217,  243,  238,  238,  238,  241,  241,  241,  231,
      232,  242,  234,  244,  245,  235,  246,  233,  236,  247,
      240,  237,  239,  248,  249,  243,  223,  223,  223,  175,
      259,  175,  332,  175,  260,  252,  261,  245,  244,  246,
      255,  257,  257,  257,  247,  258,  248,  249,  253,  238,
      238,  238,  241,  241,  241,  259,  262,  260,  263,  261,
      252,  264,  265,  175,  175,  255,  276,  277,  239,  332,
      269,  253,  332,  332,  270,  280,  257,  257,  257,  262,
      258,  281,  175,  263,  264,  265,  274,  274,  274,  276,
      277,  282,  278,  278,  278,  269,  279,  270,  280,  283,

      175,  274,  274,  274,  281,  275,  286,  286,  286,  288,
      287,  289,  290,  291,  282,  292,  284,  278,  278,  278,
      275,  279,  283,  175,  286,  286,  286,  295,  287,  296,
      296,  296,  288,  297,  289,  290,  291,  298,  292,  284,
      299,  175,  294,  296,  296,  296,  304,  305,  306,  175,
      332,  301,  295,  308,  308,  308,  310,  311,  297,  313,
      315,  175,  298,  299,  307,  294,  308,  308,  308,  304,
      305,  317,  320,  306,  301,  312,  321,  332,  322,  310,
      311,  323,  326,  315,  313,  328,  330,  307,  327,  332,
      332,  329,  331,  332,  317,  320,  332,  332,  312,   56,

       56,   56,   56,   57,   57,   57,   57,   67,   67,   67,
       67,   72,   72,   72,   72,   73,   73,   73,   73,   76,
       76,   76,   76,   78,   78,   78,   78,   93,   93,   93,
       93,   95,   95,   95,   95,  100,  100,  100,  100,  102,
      102,  102,  102,  113,  113,  113,  113,  119,  119,  119,
      119,  120,  120,  120,  120,  127,  127,  127,  127,  148,
      332,  148,  148,  151,  332,  151,  151,  166,  332,  166,
      166,  172,  172,  172,  172,  174,  174,  191,  332,  191,
      191,  192,  332,  192,  192,  302,  302,  302,  302,   55,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,

      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332
    } ;

static const flex_int16_t yy_chk[1159] =
    {   0,
        0,    3,    3,    3,  350,    3,    3,    4,    4,    4,
        3,    4,    4,  349,  348,   35,    4,   33,   34,    3,
        3,    3,    5,    5,    5,    4,    4,    4,   35,   36,
        5,    6,    6,    6,   33,   34,  322,   41,   42,    6,
       41,   42,   36,   64,   64,   64,    3,   65,   65,   65,
      321,  316,    4,    7,    7,    7,    7,    7,    7,    7,
        7,    7,  315,    7,   66,   66,   66,   71,   71,   71,
      312,    7,    7,    7,    7,    7,   11,   11,   11,   12,
       12,   12,  310,  304,   66,   68,   68,   68,   69,   69,
       69,   75,   81,   68,  302,   83,   69,  295,    7,    7,

        7,    8,    8,    8,    8,    8,    8,    8,    8,    8,
      293,    8,   86,   11,   75,   81,   12,   23,   83,    8,
        8,    8,    8,    8,   23,  283,  272,   23,   23,   23,
       23,   23,   23,   23,  256,   86,   11,   88,   96,   12,
       77,   77,   77,  146,   88,  255,    8,    8,    8,    9,
        9,    9,    9,    9,    9,    9,    9,    9,  323,    9,
       77,  254,   98,   96,  323,   24,  146,    9,    9,    9,
        9,    9,   24,  251,  105,   24,   24,   24,   24,   24,
       24,   24,   79,   79,   79,   79,   79,   79,   79,  105,
      250,   98,  248,  237,    9,    9,    9,   10,   10,   10,

       10,   10,   10,   10,   10,   10,  235,   10,  124,  124,
      124,  232,  105,   25,   98,   10,   10,   10,   10,   10,
       25,  231,  195,   25,   25,   25,   25,   25,   25,   25,
       74,   74,   74,   84,   84,   84,   84,   84,   84,   84,
      185,  117,   10,   10,   10,   19,  111,   19,   19,   19,
       19,   19,   19,   19,  147,  118,  111,  174,   26,   19,
       19,   19,   19,   19,   19,   26,  117,   74,   26,   26,
       26,   26,   26,   26,   26,  324,  112,  147,   19,  111,
      118,  324,   27,  172,   19,   19,   19,   19,   19,   27,
       74,  141,   27,   27,   27,   27,   27,   27,   27,  168,

      112,   19,   21,  140,   21,   21,   21,   21,   21,   21,
       21,  106,  129,  127,  106,   28,   21,   21,   21,   21,
       21,   21,   28,  112,  168,   28,   28,   28,   28,   28,
       28,   28,   90,   90,   90,   90,   90,   90,   90,  106,
      122,   21,   21,   21,   21,   21,   43,   43,   43,   43,
       43,   43,   43,   43,   43,  116,   43,  125,  125,  125,
       63,   63,   63,   63,   43,   43,   43,   43,   43,   63,
      186,   43,   91,   91,   91,   91,   91,   91,   91,  107,
       43,   63,   92,   92,   92,   92,   92,   92,   92,  103,
      102,   43,   43,   43,  187,  186,   43,  130,  130,  130,

       47,   47,   47,   43,   44,   44,   44,   44,   44,   44,
       44,   44,   44,  109,   44,   99,   48,   48,   48,  187,
      109,   47,   44,   44,   44,   44,   44,  325,  101,   44,
       47,  110,   99,  325,  110,  153,   70,   48,   44,   62,
       47,  131,  131,  131,   60,  109,   48,   55,  161,   44,
       44,   44,  156,   47,   44,  161,   48,   99,  153,  110,
       52,   44,   45,   47,  158,   58,   58,   58,   51,   48,
      133,  133,  133,   45,   58,  156,   50,   45,   45,   48,
       59,   59,   59,   58,   58,   58,   45,  158,  167,   59,
       45,   45,  126,  126,  126,  134,  134,  134,   59,   59,

       59,  169,   45,   45,  135,  135,  135,   49,   40,   45,
       58,  167,  126,   45,   45,   46,  136,  136,  136,  123,
      123,  123,  123,  177,  169,   59,   46,   39,  123,  177,
       46,   46,   82,   82,   82,   82,   82,   82,   82,   46,
      123,   32,  170,   46,   46,   31,   87,   87,   87,   87,
       87,   87,   87,   30,  177,   46,   46,   29,  114,  114,
      114,   18,   46,  171,   82,  170,   46,   46,   80,   80,
       80,   80,   80,   80,   80,  137,  137,  137,   87,  114,
       80,   80,   80,   80,   80,   80,  171,   82,  114,  138,
      138,  138,  115,  115,  115,  137,   17,  189,  114,   16,

       80,   87,  139,  139,  139,   80,   80,   80,   80,   80,
      139,  114,   15,  115,  142,  142,  142,  145,  145,  145,
      189,  114,  115,   80,   85,   85,   85,   85,   85,   85,
       85,  132,  115,  121,  121,  121,   85,   85,   85,   85,
       85,   85,  121,   14,   13,  115,    0,  178,  132,  132,
      204,  121,  121,  121,  145,  115,   85,  150,  150,  150,
      178,   85,   85,   85,   85,   85,  149,  149,  149,  188,
      188,  188,    0,  132,  132,  204,    0,  145,  121,   85,
      194,  194,  194,  178,    0,    0,  149,  152,  152,  152,
      152,  152,  152,  152,  157,  157,  157,  157,  157,  157,

      157,  163,  163,  163,  163,  163,  163,  163,  164,  164,
      164,  164,  164,  164,  164,  165,  165,  165,  165,  165,
      165,  165,  180,  181,  182,  183,  205,  180,  184,  184,
      184,  190,  196,  197,  202,    0,  181,  206,  182,  207,
      180,  183,  198,  198,  198,  199,  199,  199,    0,  184,
        0,  205,  180,  208,  190,  196,  197,  202,  184,  181,
      206,  182,  207,  180,  183,  200,  200,  200,  184,  201,
      201,  201,  203,  203,  203,  209,  208,  210,  211,  212,
        0,  184,  213,  214,  210,  211,  221,  213,  215,  216,
      214,  184,    0,  215,  212,    0,  216,  219,  209,  217,

      217,  217,  222,  218,  218,  218,  220,  220,  220,  210,
      211,  221,  213,  224,  225,  214,  226,  212,  215,  227,
      219,  216,  218,  229,  230,  222,  223,  223,  223,  233,
      240,  234,    0,  236,  242,  233,  243,  225,  224,  226,
      236,  239,  239,  239,  227,  239,  229,  230,  234,  238,
      238,  238,  241,  241,  241,  240,  244,  242,  245,  243,
      233,  246,  247,  252,  253,  236,  260,  261,  238,    0,
      252,  234,    0,    0,  253,  263,  257,  257,  257,  244,
      257,  264,  269,  245,  246,  247,  259,  259,  259,  260,
      261,  265,  262,  262,  262,  252,  262,  253,  263,  269,

      270,  274,  274,  274,  264,  259,  275,  275,  275,  276,
      275,  277,  280,  281,  265,  282,  270,  278,  278,  278,
      274,  278,  269,  284,  286,  286,  286,  288,  286,  289,
      289,  289,  276,  290,  277,  280,  281,  291,  282,  270,
      292,  294,  284,  296,  296,  296,  297,  298,  299,  301,
        0,  294,  288,  303,  303,  303,  305,  306,  290,  309,
      311,  307,  291,  292,  301,  284,  308,  308,  308,  297,
      298,  313,  317,  299,  294,  307,  320,    0,  320,  305,
      306,  320,  326,  311,  309,  328,  330,  301,  326,    0,
        0,  328,  330,    0,  313,  317,    0,    0,  307,  333,

      333,  333,  333,  334,  334,  334,  334,  335,  335,  335,
      335,  336,  336,  336,  336,  337,  337,  337,  337,  338,
      338,  338,  338,  339,  339,  339,  339,  340,  340,  340,
      340,  341,  341,  341,  341,  342,  342,  342,  342,  343,
      343,  343,  343,  344,  344,  344,  344,  345,  345,  345,
      345,  346,  346,  346,  346,  347,  347,  347,  347,  351,
        0,  351,  351,  352,    0,  352,  352,  353,    0,  353,
      353,  354,  354,  354,  354,  355,  355,  356,    0,  356,
      356,  357,    0,  357,  357,  358,  358,  358,  358,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,

      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"

/*
 * We want a reentrant scanner.
 */
/*
 * We don't use input, so don't generate code for it.
 */
#define YY_NO_INPUT 1
/*
 * We don't use unput, so don't generate code for it.
 */
/*
 * We don't read interactively from the terminal.
 */
/*
 * We want to stop processing when we get to the end of the input.
 */
/*
 * The type for the state we keep for a scanner.
 */
/*
 * We have to override the memory allocators so that we don't get
 * "unused argument" warnings from the yyscanner argument (which
 * we don't use, as we have a global memory allocator).
 *
 * We provide, as macros, our own versions of the routines generated by Flex,
 * which just call malloc()/realloc()/free() (as the Flex versions do),
 * discarding the extra argument.
 */
/*
 * The language we're scanning is case-insensitive.
 */
/*
 * We use start condition stacks.
 */
/*
 * Prefix scanner routines with "WimaxasncpDict_" rather than "yy", so this
 * scanner can coexist with other scanners.
 */
#line 69 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
	/*
	 ** wimaxasncp_dict.h
	 ** WIMAXASNCP Dictionary Import Routines
	 **
	 ** (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
	 ** (c) 2007, Stephen Croll <stephen.d.croll@gmail.com>
	 **
	 ** This library is free software; you can redistribute it and/or
	 ** modify it under the terms of the GNU Library General Public
	 ** License as published by the Free Software Foundation; either
	 ** version 2 of the License, or (at your option) any later version.
	 **
	 ** This library is distributed in the hope that it will be useful,
	 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
	 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	 ** Library General Public License for more details.
	 **
	 ** You should have received a copy of the GNU Library General Public
	 ** License along with this library; if not, write to the Free Software
	 ** Foundation, Inc., 51 Franklin Street, Fifth Floor,
	 ** Boston, MA  02110-1301, USA.
	 */

#include <glib.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
#include <stdarg.h>
#include <epan/value_string.h>
#include <epan/packet.h>	/* array_length */
#include <wsutil/file_util.h>

#include "wimaxasncp_dict.h"

/*
 * Disable diagnostics in the code generated by Flex.
 */
DIAG_OFF_FLEX

typedef struct entity_t {
	gchar *name;
	gchar *file;
	struct entity_t *next;
} entity_t;

#define ATTR_UINT(cont) do { D(("attr_uint " #cont "\t" )); yyextra->attr_uint = &(cont); yy_push_state(GET_UINT_ATTR, yyscanner); } while(0)
#define ATTR_UINT16(cont) do { D(("attr_uint16 " #cont "\t" )); yyextra->attr_uint16 = &(cont); yy_push_state(GET_UINT16_ATTR, yyscanner); } while(0)
#define ATTR_STR(cont) do { D(("attr_str " #cont "\t" )); yyextra->attr_str = &(cont); yy_push_state(GET_ATTR, yyscanner); } while(0)
#define ATTR_DECODER(cont) do { D(("attr_decoder " #cont "\t" )); yyextra->attr_uint = &(cont); yy_push_state(GET_DECODER_ATTR, yyscanner); } while(0)
#define WIMAXASNCP_IGNORE() do { D(("ignore: %s\t",yytext)); yy_push_state(IGNORE_ATTR, yyscanner); } while(0)

#define D(args) wimaxasncp_dict_debug args

#define MAX_INCLUDE_DEPTH 10
#define YY_INPUT(buf,result,max_size) { result = yyextra->current_yyinput(buf,max_size,yyscanner); }
#define YY_USER_INIT { \
	WimaxasncpDict_scanner_state_t *scanner_state = WimaxasncpDict_get_extra(yyscanner); \
	BEGIN(scanner_state->start_state); \
}
#define ECHO
#define APPEND(txt,len) append_to_buffer(txt,(int)len,yyextra)

typedef struct {
	GString *dict_error;

	const gchar *sys_dir;

	gchar *strbuf;
	guint size_strbuf;
	guint len_strbuf;

	gchar *write_ptr;
	gchar *read_ptr;

	wimaxasncp_dict_t *dict;
	wimaxasncp_dict_tlv_t *tlv;
	wimaxasncp_dict_enum_t *enumitem;
	wimaxasncp_dict_xmlpi_t *xmlpi;

	wimaxasncp_dict_tlv_t *last_tlv;
	wimaxasncp_dict_enum_t *last_enumitem;
	wimaxasncp_dict_xmlpi_t *last_xmlpi;

	entity_t *ents;

	YY_BUFFER_STATE include_stack[MAX_INCLUDE_DEPTH];
	int include_stack_ptr;
	size_t (*current_yyinput)(gchar*,size_t,yyscan_t);

	gchar **attr_str;
	guint *attr_uint;
	gint16 *attr_uint16;

	int start_state;
} WimaxasncpDict_scanner_state_t;

static guint wimaxasncp_bits(guint bits, char *n);
static gint wimaxasncp_decode_type(const gchar *name);
static void wimaxasncp_dict_debug(const gchar *fmt, ...) G_GNUC_PRINTF(1, 2);
static void append_to_buffer(const gchar *txt, int len, WimaxasncpDict_scanner_state_t *state);
static FILE *wimaxasncp_dict_open(const gchar*, const gchar*);

/*
 * Sleazy hack to suppress compiler warnings in yy_fatal_error().
 */
#define YY_EXIT_FAILURE ((void)yyscanner, 2)

/*
 * Macros for the allocators, to discard the extra argument.
 */
#define WimaxasncpDict_alloc(size, yyscanner)		(void *)malloc(size)
#define WimaxasncpDict_realloc(ptr, size, yyscanner)	(void *)realloc((char *)(ptr), (size))
#define WimaxasncpDict_free(ptr, yyscanner)		free((char *)ptr)

#line 1159 "wimaxasncp_dict.c"

#line 1161 "wimaxasncp_dict.c"

#define INITIAL 0
#define LOADING 1
#define LOADING_COMMENT 2
#define LOADING_XMLPI 3
#define ENTITY 4
#define GET_SYSTEM 5
#define GET_FILE 6
#define END_ENTITY 7
#define GET_ATTR 8
#define GET_UINT_ATTR 9
#define GET_UINT16_ATTR 10
#define BIT32 11
#define BIT16 12
#define BIT8 13
#define GET_DECODER_ATTR 14
#define END_ATTR 15
#define OUTSIDE 16
#define IN_DICT 17
#define IN_APPL 18
#define IN_TLV 19
#define IGNORE_ATTR 20
#define ENUM_ATTRS 21
#define TLV_ATTRS 22
#define XMLPI_ATTRS 23
#define XMLPI_GETKEY 24
#define XMLPI_GETVAL 25
#define XMLPI_ENDATTR 26

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE WimaxasncpDict_scanner_state_t *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

    static void yy_push_state ( int _new_state , yyscan_t yyscanner);
    
    static void yy_pop_state ( yyscan_t yyscanner );
    
    static int yy_top_state ( yyscan_t yyscanner );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 250 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"

#line 1451 "wimaxasncp_dict.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 333 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 332 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 251 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
;
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 252 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
;
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 254 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
BEGIN LOADING_COMMENT;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 255 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
;
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 256 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
BEGIN LOADING;
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 258 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
BEGIN LOADING_XMLPI;
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 259 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 260 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	yyextra->xmlpi = g_new(wimaxasncp_dict_xmlpi_t,1);
	yyextra->xmlpi->name = g_strdup(yytext);
	yyextra->xmlpi->key = NULL;
	yyextra->xmlpi->value = NULL;
	yyextra->xmlpi->next = NULL;

	if (!yyextra->dict->xmlpis) yyextra->last_xmlpi = yyextra->dict->xmlpis = yyextra->xmlpi;
	else yyextra->last_xmlpi = yyextra->last_xmlpi->next = yyextra->xmlpi;

	BEGIN XMLPI_ATTRS;
}
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 273 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
BEGIN XMLPI_GETKEY;
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 274 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ yyextra->xmlpi->key = g_strdup(yytext); BEGIN XMLPI_ATTRS; }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 276 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
BEGIN XMLPI_GETVAL;
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 277 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ yyextra->xmlpi->value = g_strdup(yytext); BEGIN XMLPI_ATTRS; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 279 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"

	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 280 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
BEGIN LOADING;
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 283 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
BEGIN ENTITY;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 284 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	entity_t *e = g_new(entity_t,1);
	D(("ENTITY: %s\n",yytext));
	e->name = g_strdup(yytext);
	e->next = yyextra->ents;
	yyextra->ents = e;
	BEGIN GET_SYSTEM;
};
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 292 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
BEGIN GET_FILE;
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 293 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	D(("GET_FILE: %s\n",yytext));
	yyextra->ents->file = g_strdup(yytext);
	BEGIN END_ENTITY;
}
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 298 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
BEGIN LOADING;
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 300 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
APPEND("<",1);
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 302 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
APPEND(">",1);
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 304 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
APPEND("/>",2);
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 306 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
APPEND("</",2);
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 308 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
APPEND(" ",1);
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 310 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
APPEND(yytext,yyleng);
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 312 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
APPEND("=",1);
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 314 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
APPEND(yytext,yyleng);
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 316 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	gchar *p = ++yytext, *temp_str;
	entity_t* e;

	while(*p != ';') p++;

	*p = '\0';

	D(("looking for entity: %s\n",yytext));

	if ( yyextra->include_stack_ptr >= MAX_INCLUDE_DEPTH ) {
		yyextra->dict_error = g_string_append(
			yyextra->dict_error, "included files nested too deeply\n");
		yyterminate();
	}

	yyextra->include_stack[yyextra->include_stack_ptr++] = YY_CURRENT_BUFFER;


	for (e = yyextra->ents; e; e = e->next) {
		if (strcmp(e->name,yytext) == 0) {
			yyin = wimaxasncp_dict_open(yyextra->sys_dir,e->file);
			D(("entity: %s filename: %s yyin: %p\n",e->name,e->file,(void*)yyin));
			if (!yyin) {
				yyterminate();
			} else {
				WimaxasncpDict__switch_to_buffer(WimaxasncpDict__create_buffer(yyin, YY_BUF_SIZE, yyscanner), yyscanner);
			}
			break;
		}
	}

	if (!e) {
		temp_str = ws_strdup_printf(
			"cannot find entity: '%s'\n", yytext);
		yyextra->dict_error = g_string_append(yyextra->dict_error, temp_str);
		g_free(temp_str);
		yyterminate();
	}

}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(LOADING):
case YY_STATE_EOF(LOADING_COMMENT):
case YY_STATE_EOF(LOADING_XMLPI):
case YY_STATE_EOF(ENTITY):
case YY_STATE_EOF(GET_SYSTEM):
case YY_STATE_EOF(GET_FILE):
case YY_STATE_EOF(END_ENTITY):
case YY_STATE_EOF(GET_ATTR):
case YY_STATE_EOF(GET_UINT_ATTR):
case YY_STATE_EOF(GET_UINT16_ATTR):
case YY_STATE_EOF(BIT32):
case YY_STATE_EOF(BIT16):
case YY_STATE_EOF(BIT8):
case YY_STATE_EOF(GET_DECODER_ATTR):
case YY_STATE_EOF(END_ATTR):
case YY_STATE_EOF(OUTSIDE):
case YY_STATE_EOF(IN_DICT):
case YY_STATE_EOF(IN_APPL):
case YY_STATE_EOF(IN_TLV):
case YY_STATE_EOF(IGNORE_ATTR):
case YY_STATE_EOF(ENUM_ATTRS):
case YY_STATE_EOF(TLV_ATTRS):
case YY_STATE_EOF(XMLPI_ATTRS):
case YY_STATE_EOF(XMLPI_GETKEY):
case YY_STATE_EOF(XMLPI_GETVAL):
case YY_STATE_EOF(XMLPI_ENDATTR):
#line 358 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	if (!yyin) yyterminate();

	fclose(yyin);
	D(("closing: %p %i\n",(void*)yyin,yyextra->include_stack_ptr));

	if ( --yyextra->include_stack_ptr < 0 ) {
		D(("DONE READING\n"));
		yyin = NULL;
		yyterminate();
	} else {
		WimaxasncpDict__delete_buffer(YY_CURRENT_BUFFER, yyscanner);
		WimaxasncpDict__switch_to_buffer(yyextra->include_stack[yyextra->include_stack_ptr], yyscanner);
		BEGIN LOADING;
	}
}
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 376 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	*yyextra->attr_str = wmem_strdup(wmem_epan_scope(), yytext);
	D(("%s\n",yytext));
	yyextra->attr_str = NULL;
	BEGIN END_ATTR;
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 383 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	*yyextra->attr_uint = (guint)strtoul(yytext,NULL,0);
	D(("%s\n",yytext););
	yyextra->attr_uint = NULL;
	BEGIN END_ATTR;
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 390 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	*yyextra->attr_uint16 = (gint16) strtol(yytext,NULL,0);
	D(("%s\n",yytext););
	yyextra->attr_uint16 = NULL;
	BEGIN END_ATTR;
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 397 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ BEGIN BIT32; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 399 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	*yyextra->attr_uint = wimaxasncp_bits(32, yytext);
	D(("WIMAXASNCP_BIT32(%s)\n",yytext););
	yyextra->attr_uint = NULL;
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 405 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ BEGIN BIT16; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 407 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	*yyextra->attr_uint = wimaxasncp_bits(16, yytext);
	D(("WIMAXASNCP_BIT16(%s)\n",yytext););
	yyextra->attr_uint = NULL;
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 413 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ BEGIN BIT8; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 415 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	*yyextra->attr_uint = wimaxasncp_bits(8, yytext);
	D(("WIMAXASNCP_BIT8(%s)\n",yytext););
	yyextra->attr_uint = NULL;
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 421 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ BEGIN END_ATTR; }
	YY_BREAK
case 39:
/* rule 39 can match eol */
YY_RULE_SETUP
#line 423 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	*yyextra->attr_uint = wimaxasncp_decode_type(yytext);
	D(("%s\n",yytext));
	yyextra->attr_uint = NULL;
	BEGIN END_ATTR;
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 430 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{	yy_pop_state(yyscanner); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 432 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	/* XXX: should go?*/
	D(("{%s}",yytext));
}
	YY_BREAK
case 42:
/* rule 42 can match eol */
YY_RULE_SETUP
#line 437 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	D(("=>%s<=\n",yytext));
	yy_pop_state(yyscanner);
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 442 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	D(("dictionary_start\n"));

	BEGIN IN_DICT;
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 448 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	D(("tlv_start\n"));

	yyextra->tlv = wmem_new0(wmem_epan_scope(), wimaxasncp_dict_tlv_t);
	yyextra->tlv->hf_root = -1;
	yyextra->tlv->hf_value = -1;
	yyextra->tlv->hf_ipv4 = -1;
	yyextra->tlv->hf_ipv6 = -1;
	yyextra->tlv->hf_bsid = -1;
	yyextra->tlv->hf_protocol = -1;
	yyextra->tlv->hf_port_low = -1;
	yyextra->tlv->hf_port_high = -1;
	yyextra->tlv->hf_ipv4_mask = -1;
	yyextra->tlv->hf_ipv6_mask = -1;
	yyextra->tlv->hf_vendor_id = -1;
	yyextra->tlv->hf_vendor_rest_of_info = -1;

	if (! yyextra->dict->tlvs )
		yyextra->last_tlv = yyextra->dict->tlvs = yyextra->tlv;
	else
		yyextra->last_tlv = yyextra->last_tlv->next = yyextra->tlv;

	BEGIN TLV_ATTRS;
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 473 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ ATTR_STR(yyextra->tlv->name); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 474 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ ATTR_STR(yyextra->tlv->description); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 475 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ ATTR_UINT16(yyextra->tlv->type); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 476 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ ATTR_DECODER(yyextra->tlv->decoder); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 477 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ ATTR_UINT(yyextra->tlv->since); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 478 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ BEGIN IN_TLV;	 }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 479 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ BEGIN IN_DICT; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 482 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	D(("enum_start\n"));

	yyextra->enumitem = wmem_new(wmem_epan_scope(), wimaxasncp_dict_enum_t);
	yyextra->enumitem->name = NULL;
	yyextra->enumitem->code = 0;
	yyextra->enumitem->next = NULL;

	if (!yyextra->tlv->enums)
		yyextra->last_enumitem = yyextra->tlv->enums = yyextra->enumitem;
	else
		yyextra->last_enumitem = yyextra->last_enumitem->next = yyextra->enumitem;

	BEGIN ENUM_ATTRS;
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 499 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ ATTR_STR(yyextra->enumitem->name); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 500 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ ATTR_UINT(yyextra->enumitem->code); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 502 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ BEGIN IN_TLV; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 503 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ BEGIN IN_TLV; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 505 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{ D(("tlv_end")); BEGIN IN_DICT; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 507 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
{
	yyterminate();
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 511 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
WIMAXASNCP_IGNORE();
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 513 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 515 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"
ECHO;
	YY_BREAK
#line 2022 "wimaxasncp_dict.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 333 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 333 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 332);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  _new_state , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( yyg->yy_start_stack_ptr >= yyg->yy_start_stack_depth )
		{
		yy_size_t new_size;

		yyg->yy_start_stack_depth += YY_START_STACK_INCR;
		new_size = (yy_size_t) yyg->yy_start_stack_depth * sizeof( int );

		if ( ! yyg->yy_start_stack )
			yyg->yy_start_stack = (int *) yyalloc( new_size , yyscanner );

		else
			yyg->yy_start_stack = (int *) yyrealloc(
					(void *) yyg->yy_start_stack, new_size , yyscanner );

		if ( ! yyg->yy_start_stack )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	yyg->yy_start_stack[yyg->yy_start_stack_ptr++] = YY_START;

	BEGIN(_new_state);
}

    static void yy_pop_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( --yyg->yy_start_stack_ptr < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN(yyg->yy_start_stack[yyg->yy_start_stack_ptr]);
}

    static int yy_top_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	return yyg->yy_start_stack[yyg->yy_start_stack_ptr - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

#define YYTABLES_NAME "yytables"

#line 515 "/build/wireshark/src/wireshark-4.0.0/plugins/epan/wimaxasncp/wimaxasncp_dict.l"


/*
 * Turn diagnostics back on, so we check the code that we've written.
 */
DIAG_ON_FLEX

static int debugging  = 0;

static void wimaxasncp_dict_debug(const gchar *fmt, ...) {
	va_list ap;

	va_start(ap, fmt);
	if (debugging) vfprintf(stderr, fmt, ap);
	va_end(ap);

	fflush(stderr);
}

static guint wimaxasncp_bits(guint bits, char *n)
{
	return 1u << ((bits - 1) - (strtoul(n, NULL, 10)));
}

static const value_string wimaxasncp_decode_type_vals[] =
{
  { WIMAXASNCP_TLV_TBD,                 "WIMAXASNCP_TLV_TBD"},
  { WIMAXASNCP_TLV_COMPOUND,            "WIMAXASNCP_TLV_COMPOUND"},
  { WIMAXASNCP_TLV_BYTES,               "WIMAXASNCP_TLV_BYTES"},
  { WIMAXASNCP_TLV_ENUM8,               "WIMAXASNCP_TLV_ENUM8"},
  { WIMAXASNCP_TLV_ENUM16,              "WIMAXASNCP_TLV_ENUM16"},
  { WIMAXASNCP_TLV_ENUM32,              "WIMAXASNCP_TLV_ENUM32"},
  { WIMAXASNCP_TLV_ETHER,               "WIMAXASNCP_TLV_ETHER"},
  { WIMAXASNCP_TLV_ASCII_STRING,        "WIMAXASNCP_TLV_ASCII_STRING"},
  { WIMAXASNCP_TLV_FLAG0,               "WIMAXASNCP_TLV_FLAG0"},
  { WIMAXASNCP_TLV_BITFLAGS8,           "WIMAXASNCP_TLV_BITFLAGS8"},
  { WIMAXASNCP_TLV_BITFLAGS16,          "WIMAXASNCP_TLV_BITFLAGS16"},
  { WIMAXASNCP_TLV_BITFLAGS32,          "WIMAXASNCP_TLV_BITFLAGS32"},
  { WIMAXASNCP_TLV_ID,                  "WIMAXASNCP_TLV_ID"},
  { WIMAXASNCP_TLV_HEX8,                "WIMAXASNCP_TLV_HEX8"},
  { WIMAXASNCP_TLV_HEX16,               "WIMAXASNCP_TLV_HEX16"},
  { WIMAXASNCP_TLV_HEX32,               "WIMAXASNCP_TLV_HEX32"},
  { WIMAXASNCP_TLV_DEC8,                "WIMAXASNCP_TLV_DEC8"},
  { WIMAXASNCP_TLV_DEC16,               "WIMAXASNCP_TLV_DEC16"},
  { WIMAXASNCP_TLV_DEC32,               "WIMAXASNCP_TLV_DEC32"},
  { WIMAXASNCP_TLV_IP_ADDRESS,          "WIMAXASNCP_TLV_IP_ADDRESS"},
  { WIMAXASNCP_TLV_IPV4_ADDRESS,        "WIMAXASNCP_TLV_IPV4_ADDRESS"},
  { WIMAXASNCP_TLV_PROTOCOL_LIST,       "WIMAXASNCP_TLV_PROTOCOL_LIST"},
  { WIMAXASNCP_TLV_PORT_RANGE_LIST,     "WIMAXASNCP_TLV_PORT_RANGE_LIST"},
  { WIMAXASNCP_TLV_IP_ADDRESS_MASK_LIST,"WIMAXASNCP_TLV_IP_ADDRESS_MASK_LIST"},
  { WIMAXASNCP_TLV_EAP,                 "WIMAXASNCP_TLV_EAP"},
  { WIMAXASNCP_TLV_VENDOR_SPECIFIC,     "WIMAXASNCP_TLV_VENDOR_SPECIFIC"},
  { 0, NULL}
};

static gint wimaxasncp_decode_type(const gchar *name)
{
	gsize i;
	for (i = 0; i < array_length(wimaxasncp_decode_type_vals) - 1; ++i)
	{
		if (strcmp(name, wimaxasncp_decode_type_vals[i].strptr) == 0)
		{
			return wimaxasncp_decode_type_vals[i].value;
		}
	}

	/* not found, emit some sort of error here? */

	return WIMAXASNCP_TLV_TBD;
}

extern void wimaxasncp_dict_unused(yyscan_t yyscanner);
void wimaxasncp_dict_unused(yyscan_t yyscanner) {
	yy_top_state(yyscanner);
}

static void append_to_buffer(const gchar *txt, int len, WimaxasncpDict_scanner_state_t *state) {

	if (state->strbuf == NULL) {
		state->read_ptr = state->write_ptr = state->strbuf = (gchar *)g_malloc(state->size_strbuf);
	}

	if (state->len_strbuf + len >= state->size_strbuf) {
		state->read_ptr = state->strbuf = (gchar *)g_realloc(state->strbuf,state->size_strbuf *= 2);
	}

	state->write_ptr = state->strbuf + state->len_strbuf;
	memcpy(state->write_ptr, txt, len + 1);
	state->len_strbuf += len;
}

static size_t file_input(gchar *buf, size_t max, yyscan_t scanner) {
	FILE *in = yyget_in(scanner);
	size_t read_cnt;

	read_cnt = fread(buf,1,max,in);

	if ( read_cnt == max ) {
		return max;
	} else if (read_cnt > 0) {
		return read_cnt;
	} else {
		return YY_NULL;
	}
}


static size_t string_input(gchar *buf, size_t max, yyscan_t scanner) {
	WimaxasncpDict_scanner_state_t *statep = yyget_extra(scanner);

	if (statep->read_ptr >= statep->write_ptr ) {
		return YY_NULL;
	} else if ( statep->read_ptr + max > statep->write_ptr ) {
		max = statep->write_ptr - statep->read_ptr;
	}

	memcpy(buf,statep->read_ptr,max);
	statep->read_ptr += max;

	return max;
}

static FILE *wimaxasncp_dict_open(
	const gchar *system_directory,
	const gchar *filename)
{
	FILE *fh;
	gchar *fname;
	if (system_directory)
	{
		fname = ws_strdup_printf("%s%s%s",
			   system_directory, G_DIR_SEPARATOR_S,filename);
	}
	else
	{
		fname = g_strdup(filename);
	}

	fh = ws_fopen(fname,"r");

	D(("fname: %s fh: %p\n",fname,(void*)fh));

	g_free(fname);


	return fh;
}

wimaxasncp_dict_t *wimaxasncp_dict_scan(
	const gchar *system_directory, const gchar *filename, int dbg,
	gchar **error) {

	WimaxasncpDict_scanner_state_t state;
	FILE *in;
	yyscan_t scanner;
	entity_t *e;

	debugging = dbg;

	state.dict_error = g_string_new("");

	state.sys_dir = system_directory;

	state.dict = g_new(wimaxasncp_dict_t,1);
	state.dict->tlvs = NULL;
	state.dict->xmlpis = NULL;

	state.strbuf = NULL;
	state.size_strbuf = 8192;
	state.len_strbuf = 0;

	state.write_ptr = NULL;
	state.read_ptr = NULL;

	state.tlv = NULL;
	state.enumitem = NULL;
	state.xmlpi = NULL;

	state.last_tlv = NULL;
	state.last_enumitem = NULL;
	state.last_xmlpi = NULL;

	state.ents = NULL;

	/*
	 * Pass 1.
	 *
	 * Reads the file, does some work, and stores a modified version
	 * of the file contents in memory.
	 */
	state.current_yyinput = file_input;
	state.include_stack_ptr = 0;

	in = wimaxasncp_dict_open(system_directory,filename);

	if (in == NULL) {
		/*
		 * Couldn't open the dictionary.
		 *
		 * Treat all failures other then ENOENT as errors?
		 */
		*error = NULL;
		return state.dict;
	}

	if (WimaxasncpDict_lex_init(&scanner) != 0) {
		D(("Can't initialize scanner: %s\n", strerror(errno)));
		fclose(in);
		g_free(state.dict);
		return NULL;
	}

	WimaxasncpDict_set_in(in, scanner);

	/* Associate the state with the scanner */
	WimaxasncpDict_set_extra(&state, scanner);

	state.start_state = LOADING;
	WimaxasncpDict_lex(scanner);

	WimaxasncpDict_lex_destroy(scanner);
	/*
	 * XXX - can the lexical analyzer terminate without closing
	 * all open input files?
	 */

	D(("\n---------------\n%s\n------- %d -------\n",
	   state.strbuf, state.len_strbuf));

	/*
	 * Pass 2.
	 *
	 * Reads the modified version of the file contents and does the
	 * rest of the work.
	 */
	state.current_yyinput = string_input;

	if (WimaxasncpDict_lex_init(&scanner) != 0) {
		D(("Can't initialize scanner: %s\n", strerror(errno)));
		fclose(in);
		g_free(state.dict);
		g_free(state.strbuf);
		return NULL;
	}

	/* Associate the state with the scanner */
	WimaxasncpDict_set_extra(&state, scanner);

	state.start_state = OUTSIDE;
	WimaxasncpDict_lex(scanner);

	WimaxasncpDict_lex_destroy(scanner);
	g_free(state.strbuf);

	e = state.ents;
	while (e)
	{
		entity_t *next = e->next;
		g_free(e->name);
		g_free(e->file);
		g_free(e);
		e = next;
	}

	if (state.dict_error->len > 0)
	{
		*error = g_string_free(state.dict_error, FALSE);
	}
	else
	{
		*error = NULL;
		g_string_free(state.dict_error, TRUE);
	}
	return state.dict;
}

void wimaxasncp_dict_free(wimaxasncp_dict_t *d) {
	wimaxasncp_dict_tlv_t *t, *tn;

#define FREE_NAMEANDOBJ(n) do { g_free(n->name); g_free(n); } while(0)

	for (t = d->tlvs; t; t = tn) {
		wimaxasncp_dict_enum_t *e, *en;
		tn = t->next;

		for (e = t->enums; e; e = en) {
			en = e->next;
			FREE_NAMEANDOBJ(e);
		}

		g_free(t->description);
		FREE_NAMEANDOBJ(t);
	}

	g_free(d);
}

void wimaxasncp_dict_print(FILE *fh, wimaxasncp_dict_t *d) {
	wimaxasncp_dict_tlv_t *tlvp;

	fprintf(fh,"\n");

	for (tlvp = d->tlvs; tlvp; tlvp = tlvp->next) {
		wimaxasncp_dict_enum_t *e;
		fprintf(fh,"TLV: %s[%u] %s[%d] %s (since %u)\n",
				tlvp->name ? tlvp->name : "-",
				tlvp->type,
				val_to_str(tlvp->decoder,
					   wimaxasncp_decode_type_vals,
					   "Unknown"),
				tlvp->decoder,
				tlvp->description ? tlvp->description : "",
            			tlvp->since);

		for (e = tlvp->enums; e; e = e->next) {
			fprintf(fh,"\tEnum: %s[%u]\n",
					e->name ? e->name : "-",
					e->code);
		}
	}
}

#ifdef TEST_WIMAXASNCP_DICT_STANDALONE
int main(int argc, char **argv) {
	wimaxasncp_dict_t *d;
	gchar *dname = NULL;
	gchar *fname;
	int i = 1;

	switch (argc) {
		case 3:
			dname = argv[i++];
		case 2:
			fname = argv[i];
			break;
		default:
			fprintf(stderr,"%s: usage [dictionary_dir] dictionary_filename\n",argv[0]);
			return 1;
	}

	d = wimaxasncp_dict_scan(dname,fname,1,&dict_error);

	if (dict_error)
	{
		printf("wimaxasncp - %s", dict_error);
		g_free(dict_error);
	}

	wimaxasncp_dict_print(stdout, d);

	return 0;
}
#endif

